@@ -70,7 +70,7 @@ def calc(Deb, Fin,G):
                                 
                                 l__old_vertex = noeuds[l__current_vertex][3]
                                 
-                                if l__successors.count(l__old_vertex) == 1:
+                                if l__successors.count(l__old_vertex) > 0:
                                     l__old_edge = l__successors.index(l__old_vertex)
                                 elif l__successors.count(l__old_vertex) == 0:
                                     if len(l__successors) % 2 == 1 and not station.LigneM in l__successorsColor and l__current_vertex != 'Saint-Lazare':
@@ -94,7 +94,7 @@ def calc(Deb, Fin,G):
                                                 #   l__newTentativeDistance = noeuds[l__current_vertex][0] + math.sqrt( (X(l__current_vertex) - X(l__successor))**2 + (Y(l__current_vertex) - Y(l__successor))**2)*.75
                                                 
                                                 if graph[l__current_vertex].colorIni.color() == station.LigneM and l__old_edge != -1:
-                                                        #print 'in the test' , l__successorsColor[l__current_edge], color(l__old_vertex).color()
+
                                                         if l__old_edge == -2:
                                                         
                                                             l__newTentativeDistance +=  00.01
