@@ -246,7 +246,7 @@ class Ui_MainWindow(QMainWindow):
     def selecLignes(self):
 #        value, ok = QInputDialog.getItem ( self.view, "Rtap : Lignes", "Selectionnez les lignes que vous voulez afficher.", const QStringList & items, int current = 0, bool editable = true, bool * ok = 0, Qt::WindowFlags flags = 0 )
         graph.clear()
-        fullList = station.Metro + station.Rer
+        fullList = station.Metro + station.Rer + station.Tram
         liste = []
 #        for line in self.Lignes[1:]:
 #            liste.append(fullList.index(line))
@@ -257,7 +257,7 @@ class Ui_MainWindow(QMainWindow):
     def selecLignesProcess(self,liste):
         reload(station)
         self.Lignes = [station.GPS]
-        fullList = station.Metro,station.Rer
+        fullList = station.Metro,station.Rer,station.Tram
         for it in liste:
             self.Lignes += fullList[it]
         self.buildGraph()
@@ -529,7 +529,7 @@ class Ui_MainWindow(QMainWindow):
                         )        
                 except KeyError:
                     graph[dep].removeCorres(dest)
-                    print dep, graph[dep].corres
+#                    print dep, graph[dep].corres
 
                 try:
                     if graph[dep].corresColor[k] == graph[dep].corresColor[k+1] and graph[dep].corresColor[k] != station.LigneM:
@@ -594,7 +594,7 @@ class Ui_MainWindow(QMainWindow):
         self.Selec = ('','')
         self.CheminItem = []
         self.Chemin = []
-        self.Lignes = [station.GPS] + station.Metro + station.Rer
+        self.Lignes = [station.GPS] + station.Metro + station.Rer+ station.Tram
 
 
         menubar = QMenuBar(self)
